Package: cfr
Title: Estimate Disease Severity and Case Ascertainment
Version: 0.2.0
Authors@R: c(
    person("Pratik R.", "Gupte", , "pratik.gupte@lshtm.ac.uk", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0001-5294-7819")),
    person("Adam", "Kucharski", , "adam.kucharski@lshtm.ac.uk", role = c("aut", "cph", "cre"),
           comment = c(ORCID = "0000-0001-8814-9421")),
    person("Tim", "Russell", , "timothy.russell@lshtm.ac.uk", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0001-5610-6080")),
    person("Joshua W.", "Lambert", , "joshua.lambert@lshtm.ac.uk", role = "rev",
           comment = c(ORCID = "0000-0001-5218-3046")),
    person("Hugo", "Gruson", , "hugo.gruson@data.org", role = "rev",
           comment = c(ORCID = "0000-0002-4094-1476")),
    person("Tim", "Taylor", , "tim.taylor@hiddenelephants.co.uk", role = "rev",
           comment = c(ORCID = "0000-0002-8587-7113")),
    person("James M.", "Azam", , "james.azam@lshtm.ac.uk", role = "rev",
           comment = c(ORCID = "0000-0001-5782-7330")),
    person("Abdoelnaser M.", "Degoot", , "abdoelnaser-mahmood.degoot@lshtm.ac.uk", role = "rev",
           comment = c(ORCID = "0000-0001-8788-2496")),
    person("Sebastian", "Funk", , "sebastian.funk@lshtm.ac.uk", role = "rev",
           comment = c(ORCID = "0000-0002-2842-3406"))
  )
Description: Estimate the severity of a disease and ascertainment of
    cases, as discussed in Nishiura et al. (2009)
    <doi:10.1371/journal.pone.0006852>.
License: MIT + file LICENSE
URL: https://github.com/epiverse-trace/cfr,
        https://epiverse-trace.github.io/cfr/
BugReports: https://github.com/epiverse-trace/cfr/issues
Depends: R (>= 3.5.0)
Imports: checkmate, stats
Suggests: bookdown, data.table, distcrete, distributional, dplyr,
        forcats, ggplot2, incidence2, knitr, magrittr, purrr,
        rmarkdown, scales, spelling, testthat (>= 3.0.0), tidyr
VignetteBuilder: knitr
Config/Needs/website: epiverse-trace/epiversetheme
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-02-21 09:51:45 UTC; akucharski
Author: Pratik R. Gupte [aut, cph] (<https://orcid.org/0000-0001-5294-7819>),
  Adam Kucharski [aut, cph, cre]
    (<https://orcid.org/0000-0001-8814-9421>),
  Tim Russell [aut, cph] (<https://orcid.org/0000-0001-5610-6080>),
  Joshua W. Lambert [rev] (<https://orcid.org/0000-0001-5218-3046>),
  Hugo Gruson [rev] (<https://orcid.org/0000-0002-4094-1476>),
  Tim Taylor [rev] (<https://orcid.org/0000-0002-8587-7113>),
  James M. Azam [rev] (<https://orcid.org/0000-0001-5782-7330>),
  Abdoelnaser M. Degoot [rev] (<https://orcid.org/0000-0001-8788-2496>),
  Sebastian Funk [rev] (<https://orcid.org/0000-0002-2842-3406>)
Maintainer: Adam Kucharski <adam.kucharski@lshtm.ac.uk>
Repository: CRAN
Date/Publication: 2025-02-21 10:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 17:29:47 UTC; unix
