# Generated by roxygen2: do not edit by hand

S3method(prepare_data,incidence2)
export(cfr_rolling)
export(cfr_static)
export(cfr_time_varying)
export(estimate_ascertainment)
export(estimate_outcomes)
export(prepare_data)
